==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/login_processor.php <==
<?php defined("HELLO") or exit(); ?>
<?php
if (isset($_GET['with'])){
  if (isset($_GET['callback'])){
	$callback = $_GET['callback'];
  } else {
	$callback = 'http://'.$_SERVER["SERVER_NAME"].dirname($_SERVER['SCRIPT_NAME']).'/login.php?log=try';
	if (isset($_GET['return'])) $callback = $callback.'&return='.rawurlencode($_GET['return']);
  }
  $error = '';
  if ($_GET['with'] == 'twitter'){
  } elseif ($_GET['with'] == 'haiku') {
	$authorize = 'http://www.hatena.ne.jp/mobile/oauth/authorize';
	// $myjson = 'http://n.hatena.com/applications/my.json';
	$reqtoken = getRequest('https://www.hatena.com/oauth/initiate', $callback, 'read_public,write_public,write_private', $conkey, $conkey_sec);
  //   var_dump($reqtoken);
	if (isset($reqtoken['error'])){
	  $error = "<p>ログインの初期処理に失敗しました。</p>\n<blockquote>{$reqtoken['error']}</blockquote>";
	  $_SESSION['oauth_stat'] = $reqtoken['stat'];
	} else {
	  $_SESSION['reqtoken'] = $reqtoken['token'];
	  $_SESSION['req_sec'] = $reqtoken['secret'];
	  $redirect = $authorize.'?oauth_token='.rawurlencode($reqtoken['token']);
	  $_SESSION['auth'] = "wait";
	  header('HTTP/1.1 303 See Other');
	  header('Location: ' . $redirect);
	}
  }
}
if ($_GET['log'] == 'try'){
	$token = 'https://www.hatena.com/oauth/token';
	$verifier = $_GET['oauth_verifier'];
	$acstoken = getAccess($token, $_SESSION['reqtoken'], $_SESSION['req_sec'], $verifier, $conkey, $conkey_sec);
	if (isset($acstoken['error'])){
	  $error = "<p>アクセストークンの取得に失敗しました。</p>\n<blockquote>{$acstoken['error']}<br />{$acstoken['body']}</blockquote>";
	  $_SESSION['auth'] = FALSE;
	  $_SESSION['oauth_stat'] = $acstoken['stat'];
// 	  var_dump($acstoken);
	} else {
	  $_SESSION['acstoken'] = $acstoken['token'];
	  $_SESSION['acs_sec'] = $acstoken['secret'];
	  parse_str($acstoken['body'], $acs_body);
	  $_SESSION['hatenaid'] = $acs_body['url_name'];
	  $_SESSION['hatenaname'] = rawurldecode($acs_body['display_name']);
	  $_SESSION['auth'] = TRUE;
	  $_SESSION['oauth_stat'] = $acstoken['stat'];
// 	  $_SESSION['reauth'] = $acstoken['stat'];
	  if (isset($_GET['image'])) $_SESSION['image'] = $_GET['image'];
	  parse_str($_SERVER['QUERY_STRING'], $parsedq);
	  foreach ($parsedq as $key => $val){
		if ($key == 'log' && $val == 'try') unset($parsedq['log']);
		if (preg_match('/^oauth_.+/', $key)) unset($parsedq[$key]);
	  }
	  $redirect = 'http://'.$_SERVER["SERVER_NAME"].$_SERVER['SCRIPT_NAME'];
	  if ($parsedq != ''){
		$redirect = $redirect.'?';
		$num = 1;
		foreach ($parsedq as $key => $val){
		  if ($num == 1) {
			$redirect = $redirect.$key.'='.rawurlencode($val);
			$num = 2;
		  } else {
			$redirect = $redirect.'&'.$key.'='.rawurlencode($val);
		  }
		}
	  }
// 	  $redirect = 'http://'.$_SERVER["SERVER_NAME"].$_SERVER['SCRIPT_NAME'];
	  header('HTTP/1.1 303 See Other');
	  header('Location: ' . $redirect);
	}
}
?>

==> yanmah2-1.8-noarch.zip: yanmah2-1.8-noarch/login_processor.php <==
<?php defined("HELLO") or exit(); ?>
<?php
if (isset($_GET['with'])){
  if (isset($_GET['callback'])){
	$callback = $_GET['callback'];
  } else {
	$callback = 'http://'.$_SERVER["SERVER_NAME"].dirname($_SERVER['SCRIPT_NAME']).'/login.php?log=try';
	if (isset($_GET['return'])) $callback = $callback.'&return='.rawurlencode($_GET['return']);
  }
  $error = '';
  if ($_GET['with'] == 'twitter'){
  } elseif ($_GET['with'] == 'haiku') {
	$authorize = 'http://www.hatena.ne.jp/mobile/oauth/authorize';
	// $myjson = 'http://n.hatena.com/applications/my.json';
	$reqtoken = getRequest('https://www.hatena.com/oauth/initiate', $callback, 'read_public,write_public,write_private', $conkey, $conkey_sec);
  //   var_dump($reqtoken);
	if (isset($reqtoken['error'])){
	  $error = "<p>ログインの初期処理に失敗しました。</p>\n<blockquote>{$reqtoken['error']}</blockquote>";
	  $_SESSION['oauth_stat'] = $reqtoken['stat'];
	} else {
	  $_SESSION['reqtoken'] = $reqtoken['token'];
	  $_SESSION['req_sec'] = $reqtoken['secret'];
	  $redirect = $authorize.'?oauth_token='.rawurlencode($reqtoken['token']);
	  $_SESSION['auth'] = "wait";
	  header('HTTP/1.1 303 See Other');
	  header('Location: ' . $redirect);
	}
  }
}
if (isset($_GET['log']) && $_GET['log'] == 'try'){
	$token = 'https://www.hatena.com/oauth/token';
	$verifier = $_GET['oauth_verifier'];
	$acstoken = getAccess($token, $_SESSION['reqtoken'], $_SESSION['req_sec'], $verifier, $conkey, $conkey_sec);
	if (isset($acstoken['error'])){
	  $error = "<p>アクセストークンの取得に失敗しました。</p>\n<blockquote>{$acstoken['error']}<br />{$acstoken['body']}</blockquote>";
	  $_SESSION['auth'] = FALSE;
	  $_SESSION['oauth_stat'] = $acstoken['stat'];
// 	  var_dump($acstoken);
	} else {
	  $_SESSION['acstoken'] = $acstoken['token'];
	  $_SESSION['acs_sec'] = $acstoken['secret'];
	  parse_str($acstoken['body'], $acs_body);
	  $_SESSION['hatenaid'] = $acs_body['url_name'];
	  $_SESSION['hatenaname'] = rawurldecode($acs_body['display_name']);
	  $_SESSION['auth'] = TRUE;
	  $_SESSION['oauth_stat'] = $acstoken['stat'];
// 	  $_SESSION['reauth'] = $acstoken['stat'];
	  if (isset($_GET['image'])) $_SESSION['image'] = $_GET['image'];
	  parse_str($_SERVER['QUERY_STRING'], $parsedq);
	  foreach ($parsedq as $key => $val){
		if ($key == 'log' && $val == 'try') unset($parsedq['log']);
		if (preg_match('/^oauth_.+/', $key)) unset($parsedq[$key]);
	  }
	  $redirect = 'http://'.$_SERVER["SERVER_NAME"].$_SERVER['SCRIPT_NAME'];
	  if ($parsedq != ''){
		$redirect = $redirect.'?';
		$num = 1;
		foreach ($parsedq as $key => $val){
		  if ($num == 1) {
			$redirect = $redirect.$key.'='.rawurlencode($val);
			$num = 2;
		  } else {
			$redirect = $redirect.'&'.$key.'='.rawurlencode($val);
		  }
		}
	  }
// 	  $redirect = 'http://'.$_SERVER["SERVER_NAME"].$_SERVER['SCRIPT_NAME'];
	  header('HTTP/1.1 303 See Other');
	  header('Location: ' . $redirect);
	}
}
?>
